ProjectUpdateRemoteConfigCall

Struct ProjectUpdateRemoteConfigCall 

pub struct ProjectUpdateRemoteConfigCall<'a, C>
where C: 'a,
{ /* private fields */ }
Update a RemoteConfig. We treat this as an always-existing resource (when it is not found in our data store, we treat it as version 0, a template with zero conditions and zero parameters). Hence there are no Create or Delete operations. Returns the updated template when successful (and the updated eTag as a response header), or an error if things go wrong. Possible error messages:

  • VALIDATION_ERROR (HTTP status 400) with additional details if the template being passed in can not be validated.
  • AUTHENTICATION_ERROR (HTTP status 401) if the request can not be authenticate (e.g. no access token, or invalid access token).
  • AUTHORIZATION_ERROR (HTTP status 403) if the request can not be authorized (e.g. the user has no access to the specified project id).
  • VERSION_MISMATCH (HTTP status 412) when trying to update when the expected eTag (passed in via the “If-match” header) is not specified, or is specified but does does not match the current eTag.
  • Internal error (HTTP status 500) for Database problems or other internal errors.

A builder for the updateRemoteConfig method supported by a project resource. It is not used directly, but through a ProjectMethods instance.

Example

Instantiate a resource method builder

use firebaseremoteconfig1::api::RemoteConfig;



// As the method needs a request, you would usually fill it with the desired information
// into the respective structure. Some of the parts shown here might not be applicable !
// Values shown here are possibly random and not representative !
let mut req = RemoteConfig::default();

// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.projects().update_remote_config(req, "project")
             .validate_only(true)
             .doit().await;

Implementations

Source

impl<'a, C> ProjectUpdateRemoteConfigCall<'a, C>
where C: Connector,

pub async fn doit(self) -> Result<(Response, RemoteConfig)>

Perform the operation you have build so far.

pub fn request( self, new_value: RemoteConfig, ) -> ProjectUpdateRemoteConfigCall<'a, C>

Sets the request property to the given value.

Even though the property as already been set when instantiating this call, we provide this method for API completeness.

pub fn project(self, new_value: &str) -> ProjectUpdateRemoteConfigCall<'a, C>

The GMP project identifier. Required. See note at the beginning of this file regarding project ids.

Sets the project path property to the given value.

Even though the property as already been set when instantiating this call, we provide this method for API completeness.

pub fn validate_only( self, new_value: bool, ) -> ProjectUpdateRemoteConfigCall<'a, C>

Optional. Defaults to false (UpdateRemoteConfig call should update the backend if there are no validation/interal errors). May be set to true to indicate that, should no validation errors occur, the call should return a “200 OK” instead of performing the update. Note that other error messages (500 Internal Error, 412 Version Mismatch, etc) may still result after flipping to false, even if getting a “200 OK” when calling with true.

Sets the validate only query property to the given value.

pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> ProjectUpdateRemoteConfigCall<'a, C>

The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.

                  It should be used to handle progress information, and to implement a certain level of resilience.

Sets the delegate property to the given value.

pub fn param<T>(self, name: T, value: T) -> ProjectUpdateRemoteConfigCall<'a, C>
where T: AsRef<str>,

Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.

Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.

Additional Parameters
  • fields (query-string) - Selector specifying which fields to include in a partial response.
  • uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
  • callback (query-string) - JSONP
  • $.xgafv (query-string) - V1 error format.
  • alt (query-string) - Data format for response.
  • access_token (query-string) - OAuth access token.
  • key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
  • quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
  • pp (query-boolean) - Pretty-print response.
  • bearer_token (query-string) - OAuth bearer token.
  • oauth_token (query-string) - OAuth 2.0 token for the current user.
  • upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).
  • prettyPrint (query-boolean) - Returns response with indentations and line breaks.