pub struct RemoteConfigCondition {
pub tag_color: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub expression: Option<String>,
}Expand description
A single RemoteConfig Condition. A list of these (because order matters) are part of a single RemoteConfig template.
This type is not used in any activity, and only used as part of another schema.
Fields
tag_color: Option<String>Optional. The display (tag) color of this condition. This serves as part of a tag (in the future, we may add tag text as well as tag color, but that is not yet implemented in the UI). This value has no affect on the semantics of the delivered config and it is ignored by the backend, except for passing it through write/read requests. Not having this value or having the “CONDITION_DISPLAY_COLOR_UNSPECIFIED” value (0) have the same meaning: Let the UI choose any valid color when displaying the condition.
name: Option<String>Required. A non empty and unique name of this condition.
description: Option<String>Optional. A description for this Condition. Length must be less than or equal to 100 characters (or more precisely, unicode code points, which is defined in java/com/google/wireless/android/config/ConstsExporter.java). A description may contain any Unicode characters
expression: Option<String>Required.