pub struct RemoteConfigParameter {
pub default_value: Option<RemoteConfigParameterValue>,
pub description: Option<String>,
pub conditional_values: Option<HashMap<String, RemoteConfigParameterValue>>,
}Expand description
While default_value and conditional_values are each optional, at least one of the two is required - otherwise, the parameter is meaningless (and an exception will be thrown by the validation logic).
This type is not used in any activity, and only used as part of another schema.
Fields
default_value: Option<RemoteConfigParameterValue>Optional - value to set the parameter to, when none of the named conditions
evaluate to true.
description: Option<String>Optional. A description for this Parameter. Length must be less than or equal to 100 characters (or more precisely, unicode code points, which is defined in java/com/google/wireless/android/config/ConstsExporter.java). A description may contain any Unicode characters
conditional_values: Option<HashMap<String, RemoteConfigParameterValue>>Optional - a map of (condition_name, value). The condition_name of the highest priority (the one listed first in the conditions array) determines the value of this parameter.