pub struct RemoteConfigParameterValue {
pub value: Option<String>,
pub use_in_app_default: Option<bool>,
}Expand description
A RemoteConfigParameter’s “value” (either the default value, or the value
associated with a condition name) is either a string, or the
“use_in_app_default” indicator (which means to leave out the parameter from
the returned <key, value> map that is the output of the parameter fetch).
We represent the “use_in_app_default” as a bool, but (when using the boolean
instead of the string) it should always be true.
This type is not used in any activity, and only used as part of another schema.
Fields
value: Option<String>the string to set the parameter to
use_in_app_default: Option<bool>if true, omit the parameter from the map of fetched parameter values